@@ -31,6 +31,8 @@
 
 #include <libebackend/libebackend.h>
 
+#include "e-util/e-util.h"
+
 #include "e-composer-actions.h"
 #include "e-composer-header-table.h"
 
@@ -81,6 +83,8 @@ struct _EMsgComposerPrivate {
 
 	GtkWidget *address_dialog;
 
+	EMenuBar *menu_bar;
+
 	gchar *mime_type;
 	gchar *mime_body;
 	gchar *charset;
@@ -89,6 +93,7 @@ struct _EMsgComposerPrivate {
 	guint32 mode_post : 1;
 	guint32 in_signature_insert : 1;
 	guint32 application_exiting : 1;
+	guint32 is_imip : 1;
 
 	CamelMimeMessage *redirect;
 
@@ -121,6 +126,12 @@ struct _EMsgComposerPrivate {
 	gulong drag_data_received_handler_id;
 
 	gchar *previous_identity_uid;
+
+	guint content_hash_ref_count; /* when reaches 0, the content_hash is freed; to be able to reuse it */
+	EContentEditorContentHash *content_hash;
+
+	GCancellable *load_signature_cancellable;
+	EAttachment *alternative_body_attachment; /* not referenced, only used for pointer comparison  */
 };
 
 void		e_composer_private_constructed	(EMsgComposer *composer);
@@ -144,6 +155,10 @@ gboolean	e_composer_selection_is_base64_uris
 gboolean	e_composer_selection_is_image_uris
 						(EMsgComposer *composer,
 						 GtkSelectionData *selection);
+gboolean	e_composer_selection_is_moz_url_image
+						(EMsgComposer *composer,
+						 GtkSelectionData *selection,
+						 gchar **out_moz_url);
 void		e_composer_update_signature	(EMsgComposer *composer);
 void		e_composer_emit_before_destroy	(EMsgComposer *composer);
 
