@@ -141,7 +141,7 @@ void		e_utils_get_theme_color_color	(GtkWidget *widget,
 void		e_utils_shade_color		(const GdkRGBA *a,
 						 GdkRGBA *b,
 						 gdouble mult);
-
+gdouble		e_utils_get_color_brightness	(const GdkRGBA *rgba);
 GdkRGBA		e_utils_get_text_color_for_background
 						(const GdkRGBA *bg_rgba);
 
@@ -249,6 +249,14 @@ gboolean	e_binding_transform_text_non_null
 						 const GValue *source_value,
 						 GValue *target_value,
 						 gpointer user_data);
+gboolean	e_binding_transform_text_to_uri	(GBinding *binding,
+						 const GValue *source_value,
+						 GValue *target_value,
+						 gpointer not_used);
+gboolean	e_binding_transform_uri_to_text	(GBinding *binding,
+						 const GValue *source_value,
+						 GValue *target_value,
+						 gpointer not_used);
 
 GBinding *	e_binding_bind_object_text_property
 						(gpointer source,
@@ -280,6 +288,8 @@ void		e_signal_disconnect_notify_handler
 
 GSettings *	e_util_ref_settings		(const gchar *schema_id);
 void		e_util_cleanup_settings		(void);
+GdkPixbuf *	e_misc_util_ref_pixbuf		(const gchar *filename,
+						 GError **error);
 gboolean	e_util_prompt_user		(GtkWindow *parent,
 						 const gchar *settings_schema,
 						 const gchar *promptkey,
@@ -303,41 +313,6 @@ gchar *		e_util_save_image_from_clipboard
 gboolean	e_util_check_gtk_bindings_in_key_press_event_cb
 						(GtkWidget *widget,
 						 GdkEvent *event);
-void		e_util_claim_dbus_proxy_call_error
-						(GDBusProxy *dbus_proxy,
-						 const gchar *method_name,
-						 const GError *in_error);
-void		e_util_invoke_g_dbus_proxy_call_with_error_check
-						(GDBusProxy *dbus_proxy,
-						 const gchar *method_name,
-						 GVariant *parameters,
-						 GCancellable *cancellable);
-void		e_util_invoke_g_dbus_proxy_call_with_error_check_full
-						(GDBusProxy *dbus_proxy,
-						 const gchar *method_name,
-						 GVariant *parameters,
-						 GDBusCallFlags flags,
-						 gint timeout_msec,
-						 GCancellable *cancellable);
-GVariant *	e_util_invoke_g_dbus_proxy_call_sync_wrapper_with_error_check
-						(GDBusProxy *dbus_proxy,
-						 const gchar *method_name,
-						 GVariant *parameters,
-						 GCancellable *cancellable);
-GVariant *	e_util_invoke_g_dbus_proxy_call_sync_wrapper
-						(GDBusProxy *dbus_proxy,
-						 const gchar *method_name,
-						 GVariant *parameters,
-						 GCancellable *cancellable,
-						 GError **error);
-GVariant *	e_util_invoke_g_dbus_proxy_call_sync_wrapper_full
-						(GDBusProxy *dbus_proxy,
-						 const gchar *method_name,
-						 GVariant *parameters,
-						 GDBusCallFlags flags,
-						 gint timeout_msec,
-						 GCancellable *cancellable,
-						 GError **error);
 void		e_util_save_file_chooser_folder	(GtkFileChooser *file_chooser);
 void		e_util_load_file_chooser_folder	(GtkFileChooser *file_chooser);
 gboolean	e_util_get_webkit_developer_mode_enabled
@@ -351,15 +326,23 @@ void		e_util_resize_window_for_screen	(GtkWindow *window,
 						 const GSList *children); /* GtkWidget * */
 gboolean	e_util_query_ldap_root_dse_sync	(const gchar *host,
 						 guint16 port,
+						 ESourceLDAPSecurity security,
 						 gchar ***out_root_dse,
 						 GCancellable *cancellable,
 						 GError **error);
+gchar *		e_util_get_uri_tooltip		(const gchar *uri);
 gchar *		e_util_get_language_name	(const gchar *language_tag);
 gboolean	e_util_get_language_info	(const gchar *language_tag,
 						 gchar **out_language_name,
 						 gchar **out_country_name);
 void		e_misc_util_free_global_memory	(void);
 gboolean	e_util_can_preview_filename	(const gchar *filename);
+void		e_util_markup_append_escaped	(GString *buffer,
+						 const gchar *format,
+						 ...) G_GNUC_PRINTF (2, 3);
+void		e_util_markup_append_escaped_text
+						(GString *buffer,
+						 const gchar *text);
 
 typedef struct _ESupportedLocales {
 	const gchar *code;	/* like 'en' */
@@ -370,6 +353,15 @@ void		e_util_enum_supported_locales	(void);
 const ESupportedLocales *
 		e_util_get_supported_locales	(void);
 
+void		e_util_ensure_scrolled_window_height
+						(GtkScrolledWindow *scrolled_window);
+void		e_util_make_safe_filename	(gchar *filename);
+gboolean	e_util_setup_toolbar_icon_size	(GtkToolbar *toolbar,
+						 GtkIconSize default_size);
+gboolean	e_util_get_use_header_bar	(void);
+void		e_open_map_uri			(GtkWindow *parent,
+						 const gchar *location);
+
 G_END_DECLS
 
 #endif /* E_MISC_UTILS_H */
