@@ -152,6 +152,7 @@ typedef enum {
  * @E_CONTENT_EDITOR_INSERT_TEXT_PLAIN:
  * @E_CONTENT_EDITOR_INSERT_CONVERT_PREFER_PRE: Set when should convert plain text into &lt;pre&gt; instead of &lt;div&gt;. Since 3.40
  * @E_CONTENT_EDITOR_INSERT_CLEANUP_SIGNATURE_ID: Set when should cleanup signature ID in the body. Since 3.42
+ * @E_CONTENT_EDITOR_INSERT_FROM_PLAIN_TEXT: Set when the HTML source is a plain text editor. Since: 3.48
  *
  * Since: 3.22
  **/
@@ -163,7 +164,8 @@ typedef enum {
 	E_CONTENT_EDITOR_INSERT_TEXT_HTML		= 1 << 3,
 	E_CONTENT_EDITOR_INSERT_TEXT_PLAIN		= 1 << 4,
 	E_CONTENT_EDITOR_INSERT_CONVERT_PREFER_PRE	= 1 << 5,
-	E_CONTENT_EDITOR_INSERT_CLEANUP_SIGNATURE_ID	= 1 << 6
+	E_CONTENT_EDITOR_INSERT_CLEANUP_SIGNATURE_ID	= 1 << 6,
+	E_CONTENT_EDITOR_INSERT_FROM_PLAIN_TEXT 	= 1 << 7
 } EContentEditorInsertContentFlags;
 
 /**
@@ -572,6 +574,7 @@ typedef enum {
  * @DND_TARGET_TYPE_TEXT_PLAIN: text/plain
  * @DND_TARGET_TYPE_STRING: STRING
  * @DND_TARGET_TYPE_TEXT_PLAIN_UTF8: text/plain;charser=utf-8
+ * @E_DND_TARGET_TYPE_TEXT_X_MOZ_URL: text/x-moz-url ; Since:3.52
  *
  * Drag and drop targets supported by EContentEditor.
  *
@@ -584,7 +587,8 @@ typedef enum {
 	E_DND_TARGET_TYPE_UTF8_STRING,
 	E_DND_TARGET_TYPE_TEXT_PLAIN,
 	E_DND_TARGET_TYPE_STRING,
-	E_DND_TARGET_TYPE_TEXT_PLAIN_UTF8
+	E_DND_TARGET_TYPE_TEXT_PLAIN_UTF8,
+	E_DND_TARGET_TYPE_TEXT_X_MOZ_URL
 } EDnDTargetType;
 
 /**
@@ -647,6 +651,8 @@ typedef enum {
  * @E_MARKDOWN_HTML_TO_TEXT_FLAG_NONE: no flag set
  * @E_MARKDOWN_HTML_TO_TEXT_FLAG_PLAIN_TEXT: disallow any HTML, save in pure plain text
  * @E_MARKDOWN_HTML_TO_TEXT_FLAG_COMPOSER_QUIRKS: enable composer quirks to post-process the text
+ * @E_MARKDOWN_HTML_TO_TEXT_FLAG_SIGNIFICANT_NL: whether new lines in the text are significant,
+ *    aka whether they work the same as the &lt;br&gt; elements. Since: 3.48
  *
  * Flags used in e_markdown_util_html_to_text().
  *
@@ -655,15 +661,36 @@ typedef enum {
 typedef enum { /*< flags >*/
 	E_MARKDOWN_HTML_TO_TEXT_FLAG_NONE		= 0,
 	E_MARKDOWN_HTML_TO_TEXT_FLAG_PLAIN_TEXT		= 1 << 0,
-	E_MARKDOWN_HTML_TO_TEXT_FLAG_COMPOSER_QUIRKS	= 1 << 1
+	E_MARKDOWN_HTML_TO_TEXT_FLAG_COMPOSER_QUIRKS	= 1 << 1,
+	E_MARKDOWN_HTML_TO_TEXT_FLAG_SIGNIFICANT_NL	= 1 << 2
 } EMarkdownHTMLToTextFlags;
 
+/**
+ * EMarkdownTextToHTMLFlags:
+ * @E_MARKDOWN_TEXT_TO_HTML_FLAG_NONE: no flag set
+ * @E_MARKDOWN_TEXT_TO_HTML_FLAG_INCLUDE_SOURCEPOS: include source position in the generated HTML
+ *
+ * Flags used in e_markdown_util_text_to_html_full().
+ *
+ * Since: 3.48
+ **/
+typedef enum { /*< flags >*/
+	E_MARKDOWN_TEXT_TO_HTML_FLAG_NONE		= 0,
+	E_MARKDOWN_TEXT_TO_HTML_FLAG_INCLUDE_SOURCEPOS	= 1 << 0
+} EMarkdownTextToHTMLFlags;
+
 typedef enum {
 	E_TOOLBAR_ICON_SIZE_DEFAULT	= 0,
 	E_TOOLBAR_ICON_SIZE_SMALL	= 1,
 	E_TOOLBAR_ICON_SIZE_LARGE	= 2
 } EToolbarIconSize;
 
+typedef enum {
+	E_PREFER_SYMBOLIC_ICONS_NO	= 0,
+	E_PREFER_SYMBOLIC_ICONS_YES	= 1,
+	E_PREFER_SYMBOLIC_ICONS_AUTO	= 2
+} EPreferSymbolicIcons;
+
 G_END_DECLS
 
 #endif /* E_UTIL_ENUMS_H */
