@@ -40,9 +40,6 @@ void		mail_receive_service		(CamelService *service);
 void		mail_send			(EMailSession *session);
 void		mail_send_immediately		(EMailSession *session);
 
-/* setup auto receive stuff */
-void		mail_autoreceive_init		(EMailSession *session);
-
 G_END_DECLS
 
 #endif /* MAIL_SEND_RECV_H */
